CieLch class

Inheritance

Constructors

CieLch(double l, double c, double h)
const

Properties

c → double
finalinherited
h → double
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
l → double
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCieLab() → CieLab
toLab() → List<double>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited