Lch class abstract

Implementers

Constructors

Lch(double l, double c, double h)
const

Properties

c → double
final
h → double
final
hashCode → int
The hash code for this object.
no setterinherited
l → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLab() → List<double>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited