ColorScheme class abstract

Implementers
Available extensions

Constructors

ColorScheme()
const

Properties

accent1 → ColorSwatch
no setter
accent2 → ColorSwatch
no setter
accent3 → ColorSwatch
no setter
accentColors → List<ColorSwatch>
no setter
asColors → MonetColors

Available on ColorScheme, provided by the SchemeToColors extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
neutral1 → ColorSwatch
no setter
neutral2 → ColorSwatch
no setter
neutralColors → List<ColorSwatch>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited