DynamicColorScheme class

Inheritance
Available extensions

Constructors

DynamicColorScheme({required ColorScheme targetColors, required Color primaryColor, double chromaMultiplier = 1.0, bool accurateShades = true})
const

Properties

accent1 → ColorSwatch
no setteroverride
accent2 → ColorSwatch
no setteroverride
accent3 → ColorSwatch
no setteroverride
accentColors → List<ColorSwatch>
no setterinherited
accurateShades → bool
final
asColors → MonetColors

Available on ColorScheme, provided by the SchemeToColors extension

no setter
chromaMultiplier → double
final
hashCode → int
The hash code for this object.
no setterinherited
neutral1 → ColorSwatch
no setteroverride
neutral2 → ColorSwatch
no setteroverride
neutralColors → List<ColorSwatch>
no setterinherited
primaryAccent → Oklch
no setter
primaryColor → Color
final
primaryNeutral → Oklch
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetColors → ColorScheme
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited