TargetColors class

Inheritance
Available extensions

Constructors

TargetColors([double chromaFactor = 1.0])
const

Properties

accent1 → ColorSwatch
no setteroverride
accent2 → ColorSwatch
no setteroverride
accent3 → ColorSwatch
no setteroverride
accentColors → List<ColorSwatch>
no setterinherited
asColors → MonetColors

Available on ColorScheme, provided by the SchemeToColors extension

no setter
chromaFactor → double
final
hashCode → int
The hash code for this object.
no setterinherited
neutral1 → ColorSwatch
no setteroverride
neutral2 → ColorSwatch
no setteroverride
neutralColors → List<ColorSwatch>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

accent1Chroma → const double
accent2Chroma → const double
accent3Chroma → const double
lightnessMap → const Map<int, double>
Lightness from AOSP defaults
lstarLightnessMap → const Map<int, double>
Lightness map in CIELAB L*
neutral1Chroma → const double
neutral2Chroma → const double